<?php

namespace Drupal\modules_weight\Utility;

/**
 * Provides module internal helper methods.
 *
 * @ingroup utility
 */
class InternalFunctions {

  /**
   * Prepares the delta for the weight field on the administration form.
   *
   * If a module has a weight higher then 100 (or lower than 100), it will use
   * that value as delta and the '#weight' field will turn into a textfield most
   * likely.
   *
   * @param int $weight
   *   The weight.
   *
   * @return int
   *   The weight.
   */
  public static function prepareDelta($weight) {
    $delta = 100;

    // Typecasting to int.
    $weight = (int) $weight;

    if ($weight > $delta) {
      return $weight;
    }

    if ($weight < -100) {
      return $weight * -1;
    }

    return $delta;
  }

  /**
   * Return the modules list ordered by the modules weight.
   *
   * @param bool $force
   *   Force to show the core modules.
   *
   * @return array
   *   The modules list.
   */
  public static function modulesList($force = FALSE) {
    // If we don't force we need to check the configuration variable.
    if (!$force) {
      // Getting the config to know if we should show or not the core modules.
      $force = \Drupal::service('config.factory')->get('modules_weight.settings')->get('show_system_modules');
    }
    // Getting the modules list.
    $modules = \Drupal::service('modules_weight')->getModulesList($force);

    return $modules;
  }

}
